================
Fairness Metrics
================

:mod:`aif360.metrics`
=====================

.. automodule:: aif360.metrics
    :no-members:
    :no-inherited-members:

.. currentmodule:: aif360

.. autosummary::
   :toctree: generated/
   :template: class.rst

   metrics.DatasetMetric
   metrics.BinaryLabelDatasetMetric
   metrics.ClassificationMetric
   metrics.SampleDistortionMetric
   metrics.MDSSClassificationMetric

:mod:`aif360.metrics.utils`
===========================

.. automodule:: aif360.metrics.utils
    :no-members:
    :no-inherited-members:

.. currentmodule:: aif360

.. autosummary::
   :toctree: generated/
   :template: base.rst

   metrics.utils.compute_boolean_conditioning_vector
   metrics.utils.compute_num_instances
   metrics.utils.compute_num_pos_neg
   metrics.utils.compute_num_TF_PN
   metrics.utils.compute_num_gen_TF_PN
   metrics.utils.compute_distance